@@ -1,15 +1,36 @@
-/* vim: set sw=4 ts=4 sts=4 et: */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#undef alloca
+#ifdef HAVE_ALLOCA_H
+# include <alloca.h>
+#elif defined __GNUC__
+# define alloca __builtin_alloca
+#elif defined _AIX
+# define alloca __alloca
+#elif defined _MSC_VER
+# include <malloc.h>
+# define alloca _alloca
+#else
+# include <stddef.h>
+# ifdef  __cplusplus
+extern "C"
+# endif
+void *alloca (size_t);
+#endif
+
 #include <stdio.h>
 #include <string.h>
+#include <limits.h>
+#include <unistd.h>
 
 #include "Efreet.h"
 #include "efreet_private.h"
 
+static Efreet_Version _version = { VMAJ, VMIN, VMIC, VREV };
+EAPI Efreet_Version *efreet_version = &_version;
+
 #ifdef _WIN32
 # define EFREET_PATH_SEP ';'
 #else
@@ -22,6 +43,7 @@ static const char *xdg_config_home = NULL;
 static const char *xdg_cache_home = NULL;
 static Eina_List  *xdg_data_dirs = NULL;
 static Eina_List  *xdg_config_dirs = NULL;
+static const char *hostname = NULL;
 
 /* define macros and variable for using the eina logging system  */
 #ifdef EFREET_MODULE_LOG_DOM 
@@ -44,11 +66,12 @@ static Eina_List  *efreet_dirs_get(const char *key,
 int
 efreet_base_init(void)
 {
-    _efreet_base_log_dom = eina_log_domain_register("Efreet_base", EFREET_DEFAULT_LOG_COLOR);
+    _efreet_base_log_dom = eina_log_domain_register
+      ("efreet_base", EFREET_DEFAULT_LOG_COLOR);
     if (_efreet_base_log_dom < 0)
     {
-	ERROR("Efreet: Could not create a log domain for efreet_base.\n");
-	return 0;
+        ERROR("Efreet: Could not create a log domain for efreet_base.\n");
+        return 0;
     }
     return 1;
 }
@@ -69,6 +92,8 @@ efreet_base_shutdown(void)
     IF_FREE_LIST(xdg_data_dirs, eina_stringshare_del);
     IF_FREE_LIST(xdg_config_dirs, eina_stringshare_del);
 
+    IF_RELEASE(hostname);
+
     eina_log_domain_unregister(_efreet_base_log_dom);
 }
 
@@ -76,8 +101,10 @@ efreet_base_shutdown(void)
  * @internal
  * @return Returns the users home directory
  * @brief Gets the users home directory and returns it.
+ *
+ * Needs EAPI because of helper binaries
  */
-const char *
+EAPI const char *
 efreet_home_dir_get(void)
 {
     if (efreet_home_dir) return efreet_home_dir;
@@ -126,11 +153,11 @@ efreet_data_dirs_get(void)
     if (xdg_data_dirs) return xdg_data_dirs;
 
 #ifdef _WIN32
-    snprintf(buf, 4096, "%s\\Efl;" PACKAGE_DATA_DIR ";/usr/share", getenv("APPDATA"));
+    snprintf(buf, 4096, "%s\\Efl;" PACKAGE_DATA_DIR ";/usr/share;/usr/local/share", getenv("APPDATA"));
     xdg_data_dirs = efreet_dirs_get("XDG_DATA_DIRS", buf);
 #else
     xdg_data_dirs = efreet_dirs_get("XDG_DATA_DIRS",
-                            PACKAGE_DATA_DIR ":/usr/share");
+                            PACKAGE_DATA_DIR ":/usr/share:/usr/local/share");
 #endif
     return xdg_data_dirs;
 }
@@ -176,10 +203,27 @@ efreet_cache_home_get(void)
     return xdg_cache_home;
 }
 
+/**
+ * @return Returns the current hostname
+ * @brief Returns the current hostname or empty string if not found
+ */
+EAPI const char *
+efreet_hostname_get(void)
+{
+    char buf[256];
+
+    if (hostname) return hostname;
+    if (gethostname(buf, sizeof(buf)) < 0)
+        hostname = eina_stringshare_add("");
+    else
+        hostname = eina_stringshare_add(buf);
+    return hostname;
+}
+
 /**
  * @internal
- * @param key: The environemnt key to lookup
- * @param fallback: The fallback value to use
+ * @param key The environemnt key to lookup
+ * @param fallback The fallback value to use
  * @return Returns the directory related to the given key or the fallback
  * @brief This trys to determine the correct directory name given the
  * environment key @a key and fallbacks @a fallback.
@@ -198,7 +242,8 @@ efreet_dir_get(const char *key, const char *fallback)
 
         user = efreet_home_dir_get();
         len = strlen(user) + strlen(fallback) + 1;
-        dir = malloc(sizeof(char) * len);
+        dir = malloc(len);
+        if (!dir) return NULL;
         snprintf(dir, len, "%s%s", user, fallback);
 
         t = eina_stringshare_add(dir);
@@ -211,8 +256,8 @@ efreet_dir_get(const char *key, const char *fallback)
 
 /**
  * @internal
- * @param key: The environment key to lookup
- * @param fallback: The fallback value to use
+ * @param key The environment key to lookup
+ * @param fallback The fallback value to use
  * @return Returns a list of directories specified by the given key @a key
  * or from the list of fallbacks in @a fallback.
  * @brief Creates a list of directories as given in the environment key @a
@@ -224,27 +269,40 @@ efreet_dirs_get(const char *key, const char *fallback)
     Eina_List *dirs = NULL;
     const char *path;
     char *tmp, *s, *p;
+    char ts[PATH_MAX];
+    size_t len;
 
     path = getenv(key);
     if (!path || (path[0] == '\0')) path = fallback;
 
     if (!path) return dirs;
 
-    tmp = strdup(path);
+    len = strlen(path) + 1;
+    tmp = alloca(len);
+    memcpy(tmp, path, len);
     s = tmp;
     p = strchr(s, EFREET_PATH_SEP);
     while (p)
     {
         *p = '\0';
         if (!eina_list_search_unsorted(dirs, EINA_COMPARE_CB(strcmp), s))
-            dirs = eina_list_append(dirs, (void *)eina_stringshare_add(s));
+        {
+            // resolve path properly/fully to remove path//path2 to
+            // path/path2, path/./path2 to path/path2 etc.
+            if (realpath(s, ts))
+                dirs = eina_list_append(dirs, (void *)eina_stringshare_add(ts));
+        }
 
         s = ++p;
         p = strchr(s, EFREET_PATH_SEP);
     }
     if (!eina_list_search_unsorted(dirs, EINA_COMPARE_CB(strcmp), s))
-      dirs = eina_list_append(dirs, (void *)eina_stringshare_add(s));
-    FREE(tmp);
+    {
+        // resolve path properly/fully to remove path//path2 to
+        // path/path2, path/./path2 to path/path2 etc.
+        if (realpath(s, ts))
+            dirs = eina_list_append(dirs, (void *)eina_stringshare_add(ts));
+    }
 
     return dirs;
 }
