@@ -1,14 +1,34 @@
-/* vim: set sw=4 ts=4 sts=4 et: */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#undef alloca
+#ifdef HAVE_ALLOCA_H
+# include <alloca.h>
+#elif defined __GNUC__
+# define alloca __builtin_alloca
+#elif defined _AIX
+# define alloca __alloca
+#elif defined _MSC_VER
+# include <malloc.h>
+# define alloca _alloca
+#else
+# include <stddef.h>
+# ifdef  __cplusplus
+extern "C"
+# endif
+void *alloca (size_t);
+#endif
+
 #include <sys/types.h>
 #include <unistd.h>
 #include <limits.h>
 #include <ctype.h>
 
+#ifdef _WIN32
+# include <winsock2.h>
+#endif
+
 #include <Ecore.h>
 #include <Ecore_File.h>
 
@@ -121,9 +141,9 @@ static char *efreet_string_append_char(char *dest, int *size,
 
 
 /**
- * @param desktop: The desktop file to work with
- * @param files: The files to be substituted into the exec line
- * @param data: The data pointer to pass
+ * @param desktop The desktop file to work with
+ * @param files The files to be substituted into the exec line
+ * @param data The data pointer to pass
  * @return Returns the Ecore_Exce for @a desktop
  * @brief Parses the @a desktop exec line and returns an Ecore_Exe.
  */
@@ -134,11 +154,11 @@ efreet_desktop_exec(Efreet_Desktop *desktop, Eina_List *files, void *data)
 }
 
 /**
- * @param desktop: the desktop entry
- * @param files: an eina list of file names to execute, as either absolute paths,
+ * @param desktop the desktop entry
+ * @param files an eina list of file names to execute, as either absolute paths,
  * relative paths, or uris
- * @param func: a callback to call for each prepared command line
- * @param data: user data passed to the callback
+ * @param func a callback to call for each prepared command line
+ * @param data user data passed to the callback
  * @return Returns the return value of @p func on success or NULL on failure
  * @brief Get a command to use to execute a desktop entry.
  */
@@ -150,8 +170,8 @@ efreet_desktop_command_get(Efreet_Desktop *desktop, Eina_List *files,
 }
 
 /**
- * @param desktop: the desktop entry
- * @param files an eina list of local files, as absolute paths, local paths, or file:// uris (or NULL to get exec string with no files appended)
+ * @param desktop the desktop entry
+ * @param files an eina list of local files, as absolute paths, local paths, or file// uris (or NULL to get exec string with no files appended)
  * @return Returns an eina list of exec strings
  * @brief Get the command to use to execute a desktop entry
  *
@@ -197,12 +217,12 @@ efreet_desktop_command_local_get(Efreet_Desktop *desktop, Eina_List *files)
 }
 
 /**
- * @param desktop: the desktop entry
- * @param files: an eina list of file names to execute, as either absolute paths,
+ * @param desktop the desktop entry
+ * @param files an eina list of file names to execute, as either absolute paths,
  * relative paths, or uris
- * @param cb_command: a callback to call for each prepared command line
- * @param cb_progress: a callback to get progress for the downloads
- * @param data: user data passed to the callback
+ * @param cb_command a callback to call for each prepared command line
+ * @param cb_progress a callback to get progress for the downloads
+ * @param data user data passed to the callback
  * @return Returns 1 on success or 0 on failure
  * @brief Get a command to use to execute a desktop entry, and receive progress
  * updates for downloading of remote URI's passed in.
@@ -248,8 +268,11 @@ efreet_desktop_command_progress_get(Efreet_Desktop *desktop, Eina_List *files,
         Eina_List *execs;
 
         execs = efreet_desktop_command_build(command);
-        ret = efreet_desktop_command_execs_process(command, execs);
-        eina_list_free(execs);
+        if (execs)
+        {
+            ret = efreet_desktop_command_execs_process(command, execs);
+            eina_list_free(execs);
+        }
         efreet_desktop_command_free(command);
     }
 
@@ -345,7 +368,7 @@ efreet_desktop_command_execs_process(Efreet_Desktop_Command *command, Eina_List
  * processed filename information. The callback passed in to
  * efreet_desktop_command_get is called for each exec string created.
  *
- * @param command: the command to build
+ * @param command the command to build
  * @return a list of executable strings
  */
 static Eina_List *
@@ -369,6 +392,7 @@ efreet_desktop_command_build(Efreet_Desktop_Command *command)
         Efreet_Desktop_Command_File *file = eina_list_data_get(l);
 
         exec = malloc(size);
+        if (!exec) goto error;
         p = command->desktop->exec;
         len = 0;
 
@@ -376,8 +400,12 @@ efreet_desktop_command_build(Efreet_Desktop_Command *command)
         {
             if (len >= size - 1)
             {
+                char *tmp;
+
                 size = len + 1024;
-                exec = realloc(exec, size);
+                tmp = realloc(exec, size);
+                if (!tmp) goto error;
+                exec = tmp;
             }
 
             /* XXX handle fields inside quotes? */
@@ -394,6 +422,7 @@ efreet_desktop_command_build(Efreet_Desktop_Command *command)
                         {
                             exec = efreet_desktop_command_append_single(exec, &size,
                                     &len, file, *p);
+                            if (!exec) goto error;
                             file_added = 1;
                         }
                         break;
@@ -405,20 +434,24 @@ efreet_desktop_command_build(Efreet_Desktop_Command *command)
                         {
                             exec = efreet_desktop_command_append_multiple(exec, &size,
                                     &len, command, *p);
+                            if (!exec) goto error;
                             file_added = 1;
                         }
                         break;
                     case 'i':
                         exec = efreet_desktop_command_append_icon(exec, &size, &len,
                                 command->desktop);
+                        if (!exec) goto error;
                         break;
                     case 'c':
                         exec = efreet_desktop_command_append_quoted(exec, &size, &len,
                                 command->desktop->name);
+                        if (!exec) goto error;
                         break;
                     case 'k':
                         exec = efreet_desktop_command_append_quoted(exec, &size, &len,
                                 command->desktop->orig_path);
+                        if (!exec) goto error;
                         break;
                     case 'v':
                     case 'm':
@@ -456,26 +489,36 @@ efreet_desktop_command_build(Efreet_Desktop_Command *command)
                 command->desktop->orig_path, command->desktop->exec);
             if (len >= size - 1)
             {
+                char *tmp;
                 size = len + 1024;
-                exec = realloc(exec, size);
+                tmp = realloc(exec, size);
+                if (!tmp) goto error;
+                exec = tmp;
             }
             exec[len++] = ' ';
             exec = efreet_desktop_command_append_multiple(exec, &size,
                     &len, command, 'F');
+            if (!exec) goto error;
             file_added = 1;
         }
 #endif
         exec[len++] = '\0';
 
         execs = eina_list_append(execs, exec);
+        exec = NULL;
 
         /* If no file was added, then the Exec field doesn't contain any file
          * fields (fFuUdDnN). We only want to run the app once in this case. */
         if (!file_added) break;
     }
-    while ((l = eina_list_next(l)) != NULL);
+    while ((l = eina_list_next(l)));
 
     return execs;
+error:
+    IF_FREE(exec);
+    EINA_LIST_FREE(execs, exec)
+        free(exec);
+    return NULL;
 }
 
 static void
@@ -500,6 +543,7 @@ efreet_desktop_command_append_quoted(char *dest, int *size, int *len, char *src)
 {
     if (!src) return dest;
     dest = efreet_string_append(dest, size, len, "'");
+    if (!dest) return NULL;
 
     /* single quotes in src need to be escaped */
     if (strchr(src, '\''))
@@ -509,16 +553,24 @@ efreet_desktop_command_append_quoted(char *dest, int *size, int *len, char *src)
         while (*p)
         {
             if (*p == '\'')
+            {
                 dest = efreet_string_append(dest, size, len, "\'\\\'");
+                if (!dest) return NULL;
+            }
 
             dest = efreet_string_append_char(dest, size, len, *p);
+            if (!dest) return NULL;
             p++;
         }
     }
     else
+    {
         dest = efreet_string_append(dest, size, len, src);
+        if (!dest) return NULL;
+    }
 
     dest = efreet_string_append(dest, size, len, "'");
+    if (!dest) return NULL;
 
     return dest;
 }
@@ -539,10 +591,14 @@ efreet_desktop_command_append_multiple(char *dest, int *size, int *len,
         if (first)
             first = 0;
         else
+        {
             dest = efreet_string_append_char(dest, size, len, ' ');
+            if (!dest) return NULL;
+        }
 
         dest = efreet_desktop_command_append_single(dest, size, len,
                                                     file, tolower(type));
+        if (!dest) return NULL;
     }
 
     return dest;
@@ -577,6 +633,7 @@ efreet_desktop_command_append_single(char *dest, int *size, int *len,
     if (!str) return dest;
 
     dest = efreet_desktop_command_append_quoted(dest, size, len, str);
+    if (!dest) return NULL;
 
     return dest;
 }
@@ -588,14 +645,16 @@ efreet_desktop_command_append_icon(char *dest, int *size, int *len,
     if (!desktop->icon || !desktop->icon[0]) return dest;
 
     dest = efreet_string_append(dest, size, len, "--icon ");
+    if (!dest) return NULL;
     dest = efreet_desktop_command_append_quoted(dest, size, len, desktop->icon);
+    if (!dest) return NULL;
 
     return dest;
 }
 
 /**
- * @param command: the Efreet_Desktop_Comand that this file is for
- * @param file: the filname as either an absolute path, relative path, or URI
+ * @param command the Efreet_Desktop_Comand that this file is for
+ * @param file the filname as either an absolute path, relative path, or URI
  */
 static Efreet_Desktop_Command_File *
 efreet_desktop_command_file_process(Efreet_Desktop_Command *command, const char *file)
@@ -653,6 +712,7 @@ efreet_desktop_command_file_process(Efreet_Desktop_Command *command, const char
     else
     {
         char *absol = efreet_desktop_command_path_absolute(file);
+        if (!absol) goto error;
         /* process local uri/path */
         if (command->flags & EFREET_DESKTOP_EXEC_FLAG_FULLPATH)
             f->fullpath = strdup(absol);
@@ -673,11 +733,14 @@ efreet_desktop_command_file_process(Efreet_Desktop_Command *command, const char
     INF("  file: %s", f->file);
 #endif
     return f;
+error:
+    IF_FREE(f);
+    return NULL;
 }
 
 /**
  * @brief Find the local path portion of a file uri.
- * @param uri: a uri beginning with "file:"
+ * @param uri a uri beginning with "file"
  * @return the location of the path portion of the uri,
  * or NULL if the file is not on this machine
  */
@@ -760,9 +823,12 @@ efreet_desktop_cb_download_complete(void *data, const char *file __UNUSED__,
         Eina_List *execs;
 
         execs = efreet_desktop_command_build(f->command);
-        /* TODO: Need to handle the return value from efreet_desktop_command_execs_process */
-        efreet_desktop_command_execs_process(f->command, execs);
-        eina_list_free(execs);
+        if (execs)
+        {
+            /* TODO: Need to handle the return value from efreet_desktop_command_execs_process */
+            efreet_desktop_command_execs_process(f->command, execs);
+            eina_list_free(execs);
+        }
         efreet_desktop_command_free(f->command);
     }
 }
@@ -787,7 +853,7 @@ efreet_desktop_cb_download_progress(void *data,
 
 /**
  * @brief Build an absolute path from an absolute or relative one.
- * @param path: an absolute or relative path
+ * @param path an absolute or relative path
  * @return an allocated absolute path (must be freed)
  */
 static char *
@@ -809,7 +875,9 @@ efreet_desktop_command_path_absolute(const char *path)
         len = strlen(buf);
 
         if (buf[len-1] != '/') buf = efreet_string_append(buf, &size, &len, "/");
+        if (!buf) return NULL;
         buf = efreet_string_append(buf, &size, &len, path);
+        if (!buf) return NULL;
 
         return buf;
     }
@@ -831,11 +899,18 @@ efreet_string_append(char *dest, int *size, int *len, const char *src)
 
     while (l > *size - *len)
     {
+        char *tmp;
         /* we successfully appended this much */
         off += *size - *len - 1;
         *len = *size - 1;
         *size += 1024;
-        dest = realloc(dest, *size);
+        tmp = realloc(dest, *size);
+        if (!tmp)
+        {
+            free(dest);
+            return NULL;
+        }
+        dest = tmp;
         *(dest + *len) = '\0';
 
         l = eina_strlcpy(dest + *len, src + off, *size - *len);
@@ -850,8 +925,15 @@ efreet_string_append_char(char *dest, int *size, int *len, char c)
 {
     if (*len >= *size - 1)
     {
+        char *tmp;
         *size += 1024;
-        dest = realloc(dest, *size);
+        tmp = realloc(dest, *size);
+        if (!tmp)
+        {
+            free(dest);
+            return NULL;
+        }
+        dest = tmp;
     }
 
     dest[(*len)++] = c;
