@@ -1,9 +1,25 @@
-/* vim: set sw=4 ts=4 sts=4 et: */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#undef alloca
+#ifdef HAVE_ALLOCA_H
+# include <alloca.h>
+#elif defined __GNUC__
+# define alloca __builtin_alloca
+#elif defined _AIX
+# define alloca __alloca
+#elif defined _MSC_VER
+# include <malloc.h>
+# define alloca _alloca
+#else
+# include <stddef.h>
+# ifdef  __cplusplus
+extern "C"
+# endif
+void *alloca (size_t);
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -24,7 +40,7 @@
 static int _efreet_ini_log_dom = -1;
 
 static Eina_Hash *efreet_ini_parse(const char *file);
-static const char *efreet_ini_unescape(const char *str);
+static const char *efreet_ini_unescape(const char *str) EINA_ARG_NONNULL(1);
 static Eina_Bool
 efreet_ini_section_save(const Eina_Hash *hash, const void *key, void *data, void *fdata);
 static Eina_Bool
@@ -38,7 +54,8 @@ efreet_ini_value_save(const Eina_Hash *hash, const void *key, void *data, void *
 int
 efreet_ini_init(void)
 {
-    _efreet_ini_log_dom = eina_log_domain_register("Efreet_init", EFREET_DEFAULT_LOG_COLOR);
+    _efreet_ini_log_dom = eina_log_domain_register
+      ("efreet_init", EFREET_DEFAULT_LOG_COLOR);
     if (_efreet_ini_log_dom < 0)
     {
         ERROR("Efreet: Could not create a log domain for efreet_init");
@@ -59,7 +76,7 @@ efreet_ini_shutdown(void)
 }
 
 /**
- * @param file: The file to parse
+ * @param file The file to parse
  * @return Returns a new Efreet_Ini structure initialized with the contents
  * of @a file, or NULL on memory allocation failure
  * @brief Creates and initializes a new Ini structure with the contents of
@@ -185,7 +202,7 @@ efreet_ini_parse(const char *file)
             goto next_line;
         }
 
-        if (section == NULL)
+        if (!section)
         {
 //            INF("Invalid file (%s) (missing section)", file);
             goto next_line;
@@ -197,7 +214,7 @@ efreet_ini_parse(const char *file)
 
         if (sep < line_length)
         {
-            const char *key, *value;
+            char *key, *value;
             int key_end, value_start, value_end;
 
             /* trim whitespace from end of key */
@@ -234,16 +251,16 @@ efreet_ini_parse(const char *file)
                 goto next_line;
             }
 
-            key = alloca((key_end + 1) * sizeof(unsigned char));
-            value = alloca((value_end - value_start + 1) * sizeof(unsigned char));
+            key = alloca(key_end + 1);
+            value = alloca(value_end - value_start + 1);
             if (!key || !value) goto next_line;
 
-            memcpy((char*)key, line_start, key_end);
-            ((char*)key)[key_end] = '\0';
+            memcpy(key, line_start, key_end);
+            key[key_end] = '\0';
 
-            memcpy((char*)value, line_start + value_start,
+            memcpy(value, line_start + value_start,
                     value_end - value_start);
-            ((char*)value)[value_end - value_start] = '\0';
+            value[value_end - value_start] = '\0';
 
             eina_hash_del_by_key(section, key);
             eina_hash_add(section, key, efreet_ini_unescape(value));
@@ -272,7 +289,7 @@ next_line:
 }
 
 /**
- * @param ini: The Efreet_Ini to work with
+ * @param ini The Efreet_Ini to work with
  * @return Returns no value
  * @brief Frees the given Efree_Ini structure.
  */
@@ -286,8 +303,8 @@ efreet_ini_free(Efreet_Ini *ini)
 }
 
 /**
- * @param ini: The Efreet_Ini to work with
- * @param file: The file to load
+ * @param ini The Efreet_Ini to work with
+ * @param file The file to load
  * @return Returns no value
  * @brief Saves the given Efree_Ini structure.
  */
@@ -314,8 +331,8 @@ efreet_ini_save(Efreet_Ini *ini, const char *file)
 }
 
 /**
- * @param ini: The Efreet_Ini to work with
- * @param section: The section of the ini file we want to get values from
+ * @param ini The Efreet_Ini to work with
+ * @param section The section of the ini file we want to get values from
  * @return Returns 1 if the section exists, otherwise 0
  * @brief Sets the current working section of the ini file to @a section
  */
@@ -329,8 +346,8 @@ efreet_ini_section_set(Efreet_Ini *ini, const char *section)
 }
 
 /**
- * @param ini: The Efreet_Ini to work with
- * @param section: The section of the ini file we want to add
+ * @param ini The Efreet_Ini to work with
+ * @param section The section of the ini file we want to add
  * @return Returns no value
  * @brief Adds a new working section of the ini file to @a section
  */
@@ -350,8 +367,8 @@ efreet_ini_section_add(Efreet_Ini *ini, const char *section)
 }
 
 /**
- * @param ini: The Efree_Ini to work with
- * @param key: The key to lookup
+ * @param ini The Efree_Ini to work with
+ * @param key The key to lookup
  * @return Returns the string associated with the given key or NULL if not
  * found.
  * @brief Retrieves the value for the given key or NULL if none found.
@@ -365,9 +382,9 @@ efreet_ini_string_get(Efreet_Ini *ini, const char *key)
 }
 
 /**
- * @param ini: The Efree_Ini to work with
- * @param key: The key to use
- * @param value: The value to set
+ * @param ini The Efree_Ini to work with
+ * @param key The key to use
+ * @param value The value to set
  * @return Returns no value
  * @brief Sets the value for the given key
  */
@@ -381,8 +398,8 @@ efreet_ini_string_set(Efreet_Ini *ini, const char *key, const char *value)
 }
 
 /**
- * @param ini: The Efree_Ini to work with
- * @param key: The key to lookup
+ * @param ini The Efree_Ini to work with
+ * @param key The key to lookup
  * @return Returns the integer associated with the given key or -1 if not
  * found.
  * @brief Retrieves the value for the given key or -1 if none found.
@@ -401,9 +418,9 @@ efreet_ini_int_get(Efreet_Ini *ini, const char *key)
 }
 
 /**
- * @param ini: The Efree_Ini to work with
- * @param key: The key to use
- * @param value: The value to set
+ * @param ini The Efree_Ini to work with
+ * @param key The key to use
+ * @param value The value to set
  * @return Returns no value
  * @brief Sets the value for the given key
  */
@@ -419,8 +436,8 @@ efreet_ini_int_set(Efreet_Ini *ini, const char *key, int value)
 }
 
 /**
- * @param ini: The Efree_Ini to work with
- * @param key: The key to lookup
+ * @param ini The Efree_Ini to work with
+ * @param key The key to lookup
  * @return Returns the double associated with the given key or -1 if not
  * found.
  * @brief Retrieves the value for the given key or -1 if none found.
@@ -439,9 +456,9 @@ efreet_ini_double_get(Efreet_Ini *ini, const char *key)
 }
 
 /**
- * @param ini: The Efree_Ini to work with
- * @param key: The key to use
- * @param value: The value to set
+ * @param ini The Efree_Ini to work with
+ * @param key The key to use
+ * @param value The value to set
  * @return Returns no value
  * @brief Sets the value for the given key
  */
@@ -461,8 +478,8 @@ efreet_ini_double_set(Efreet_Ini *ini, const char *key, double value)
 }
 
 /**
- * @param ini: The ini struct to work with
- * @param key: The key to search for
+ * @param ini The ini struct to work with
+ * @param key The key to search for
  * @return Returns 1 if the boolean is true, 0 otherwise
  * @brief Retrieves the boolean value at key @a key from the ini @a ini
  */
@@ -480,9 +497,9 @@ efreet_ini_boolean_get(Efreet_Ini *ini, const char *key)
 }
 
 /**
- * @param ini: The ini struct to work with
- * @param key: The key to use
- * @param value: The value to set
+ * @param ini The ini struct to work with
+ * @param key The key to use
+ * @param value The value to set
  * @return Returns no value
  * @brief Sets the value for the given key
  */
@@ -496,8 +513,8 @@ efreet_ini_boolean_set(Efreet_Ini *ini, const char *key, unsigned int value)
 }
 
 /**
- * @param ini: The ini struct to work with
- * @param key: The key to search for
+ * @param ini The ini struct to work with
+ * @param key The key to search for
  * @return Returns the utf8 encoded string associated with @a key, or NULL
  *         if none found
  * @brief Retrieves the utf8 encoded string associated with @a key in the current locale or NULL if none found
@@ -522,7 +539,7 @@ efreet_ini_localestring_get(Efreet_Ini *ini, const char *key)
     if (country) maxlen += strlen(country);
     if (modifier) maxlen += strlen(modifier);
 
-    buf = malloc(maxlen * sizeof(char));
+    buf = alloca(maxlen);
 
     if (lang && modifier && country)
     {
@@ -555,15 +572,13 @@ efreet_ini_localestring_get(Efreet_Ini *ini, const char *key)
     if (!found)
         val = efreet_ini_string_get(ini, key);
 
-    FREE(buf);
-
     return val;
 }
 
 /**
- * @param ini: The ini struct to work with
- * @param key: The key to use
- * @param value: The value to set
+ * @param ini The ini struct to work with
+ * @param key The key to use
+ * @param value The value to set
  * @return Returns no value
  * @brief Sets the value for the given key
  */
@@ -585,7 +600,7 @@ efreet_ini_localestring_set(Efreet_Ini *ini, const char *key, const char *value)
     if (country) maxlen += strlen(country);
     if (modifier) maxlen += strlen(modifier);
 
-    buf = malloc(maxlen * sizeof(char));
+    buf = alloca(maxlen);
 
     if (lang && modifier && country)
         snprintf(buf, maxlen, "%s[%s_%s@%s]", key, lang, country, modifier);
@@ -599,12 +614,11 @@ efreet_ini_localestring_set(Efreet_Ini *ini, const char *key, const char *value)
         return;
 
     efreet_ini_string_set(ini, buf, value);
-    FREE(buf);
 }
 
 /**
- * @param ini: The ini struct to work with
- * @param key: The key to remove
+ * @param ini The ini struct to work with
+ * @param key The key to remove
  * @return Returns no value
  * @brief Remove the given key from the ini struct
  */
@@ -627,7 +641,6 @@ efreet_ini_unescape(const char *str)
     char *buf, *dest;
     const char *p;
 
-    if (!str) return NULL;
     if (!strchr(str, '\\')) return eina_stringshare_add(str);
     buf = alloca(strlen(str) + 1);
 
