@@ -1,5 +1,3 @@
-/* vim: set sw=4 ts=4 sts=4 et: */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -39,7 +37,7 @@ static int error = 0;
 
 /* define macros and variable for using the eina logging system  */
 
-#ifdef EFREET_MODULE_LOG_DOM 
+#ifdef EFREET_MODULE_LOG_DOM
 #undef EFREET_MODULE_LOG_DOM
 #endif
 #define EFREET_MODULE_LOG_DOM _efreet_xml_log_dom
@@ -57,11 +55,12 @@ efreet_xml_init(void)
 {
     _efreet_xml_init_count++;
     if (_efreet_xml_init_count > 1) return _efreet_xml_init_count;
-    _efreet_xml_log_dom = eina_log_domain_register("Efreet_xml", EFREET_DEFAULT_LOG_COLOR);
+    _efreet_xml_log_dom = eina_log_domain_register
+      ("efreet_xml", EFREET_DEFAULT_LOG_COLOR);
     if (_efreet_xml_log_dom < 0)
     {
         _efreet_xml_init_count--;
-        ERROR("Efreet: Could not create a log domain for Efreet_xml.");
+        ERROR("Efreet: Could not create a log domain for efreet_xml.");
         return _efreet_xml_init_count;
     }
     return _efreet_xml_init_count;
@@ -82,7 +81,7 @@ efreet_xml_shutdown(void)
 
 /**
  * @internal
- * @param file: The file to parse
+ * @param file The file to parse
  * @return Returns an Efreet_Xml structure for the given file @a file or
  * NULL on failure
  * @brief Parses the given file into an Efreet_Xml structure.
@@ -108,7 +107,7 @@ efreet_xml_new(const char *file)
 
     error = 0;
     xml = efreet_xml_parse(&data, &size);
-    if (error) goto efreet_error;
+    if (!xml || error) goto efreet_error;
 
     munmap(data, size);
     close(fd);
@@ -124,7 +123,7 @@ efreet_error:
 
 /**
  * @internal
- * @param xml: The Efree_Xml to free
+ * @param xml The Efree_Xml to free
  * @return Returns no value
  * @brief Frees up the given Efreet_Xml structure
  */
@@ -154,8 +153,8 @@ efreet_xml_del(Efreet_Xml *xml)
 }
 
 /**
- * @param xml: The xml struct to work with
- * @param key: The attribute key to look for
+ * @param xml The xml struct to work with
+ * @param key The attribute key to look for
  * @return Returns the value for the given key, or NULL if none found
  * @brief Retrieves the value for the given attribute key
  */
@@ -458,6 +457,7 @@ efreet_xml_attributes_parse(char **data, int *size,
     }
 
     *attributes = NEW(Efreet_Xml_Attribute *, count + 1);
+    if (!*attributes) goto efreet_error;
     for (i = 0; i < count; i++)
     {
         (*attributes)[i] = malloc(sizeof(Efreet_Xml_Attribute));
